@@ -32,34 +32,46 @@
 #' #cat('Type II error: ', typeII, '\n')
 
 predict.npc <- function(object, newx = NULL, pred.score = NULL, ...) {
-
-  if (object$method == "custom") {
-    if (is.null(pred.score)) {
-      stop("pred.score needed for method \"custom\".")
+    if (object$n0toosmall == 'TRUE'){
+      warning('too few class 0 observations to ensure a type I error control.')
+     return()
     }
-    pred.score = pred.score
-    if (object$sign == TRUE) {
-      pred.label = outer(pred.score, object$cutoff, ">")
+    if (object$method == "custom") {
+        if (is.null(pred.score)) {
+            stop("pred.score needed for method \"custom\".")
+        }
+        pred.score = pred.score
+        if (object$sign == TRUE) {
+            pred.label = outer(pred.score, object$cutoff, ">")
+        } else {
+            pred.label = outer(pred.score, object$cutoff, "<=")
+        }
     } else {
-      pred.label = outer(pred.score, object$cutoff, "<=")
+        colnames(newx) <- paste("x", 1:ncol(newx), sep = "")
+        if (object$split < 1) {
+            pred = pred.npc.core(object, newx)
+            pred.score = pred$pred.score
+            pred.label = pred$pred.label
+        } else {
+            pred = pred.npc.core(object[[1]], newx)
+            pred.score = pred$pred.score
+            pred.label = pred$pred.label
+
+            if (object$split > 1) {
+                for (i in 2:object$split) {
+                  pred = pred.npc.core(object[[i]], newx)
+
+                  pred.label = pred.label + pred$pred.label
+                  pred.score = pred.score + pred$pred.score
+
+                }
+            }
+            pred.label = (pred.label/object$split > 0.5)
+            pred.score = pred.score/object$split
+        }
     }
-  } else {
-    colnames(newx) <- paste("x", 1:ncol(newx), sep = "")
-    if(object$split<=1){
-      pred = pred.npc.core(object,newx)
-      pred.score = pred$pred.score
-      pred.label = pred$pred.label
-    } else {
-      pred.label = pred.npc.core(object[[1]],newx)$pred.label
-
-      for(i in 2:object$split){
-        pred.label = pred.label + pred.npc.core(object[[i]],newx)$pred.label
-      }
-      pred.label = (pred.label/object$split>0.5)
-    }
-  }
 
 
-  return(list(pred.label = pred.label, pred.score = pred.score))
+    return(list(pred.label = pred.label, pred.score = pred.score))
 
 }
